@@ -916,3 +916,105 @@
 #define GOBJECT_AVAILABLE_ENUMERATOR_IN_2_76
 #define GOBJECT_AVAILABLE_TYPE_IN_2_76
 #endif
+
+#if GLIB_VERSION_MIN_REQUIRED >= GLIB_VERSION_2_78
+#define GOBJECT_DEPRECATED_IN_2_78 GOBJECT_DEPRECATED
+#define GOBJECT_DEPRECATED_IN_2_78_FOR(f) GOBJECT_DEPRECATED_FOR (f)
+#define GOBJECT_DEPRECATED_MACRO_IN_2_78 GLIB_DEPRECATED_MACRO
+#define GOBJECT_DEPRECATED_MACRO_IN_2_78_FOR(f) GLIB_DEPRECATED_MACRO_FOR (f)
+#define GOBJECT_DEPRECATED_ENUMERATOR_IN_2_78 GLIB_DEPRECATED_ENUMERATOR
+#define GOBJECT_DEPRECATED_ENUMERATOR_IN_2_78_FOR(f) GLIB_DEPRECATED_ENUMERATOR_FOR (f)
+#define GOBJECT_DEPRECATED_TYPE_IN_2_78 GLIB_DEPRECATED_TYPE
+#define GOBJECT_DEPRECATED_TYPE_IN_2_78_FOR(f) GLIB_DEPRECATED_TYPE_FOR (f)
+#else
+#define GOBJECT_DEPRECATED_IN_2_78 _GOBJECT_EXTERN
+#define GOBJECT_DEPRECATED_IN_2_78_FOR(f) _GOBJECT_EXTERN
+#define GOBJECT_DEPRECATED_MACRO_IN_2_78
+#define GOBJECT_DEPRECATED_MACRO_IN_2_78_FOR(f)
+#define GOBJECT_DEPRECATED_ENUMERATOR_IN_2_78
+#define GOBJECT_DEPRECATED_ENUMERATOR_IN_2_78_FOR(f)
+#define GOBJECT_DEPRECATED_TYPE_IN_2_78
+#define GOBJECT_DEPRECATED_TYPE_IN_2_78_FOR(f)
+#endif
+
+#if GLIB_VERSION_MAX_ALLOWED < GLIB_VERSION_2_78
+#define GOBJECT_AVAILABLE_IN_2_78 GOBJECT_UNAVAILABLE (2, 78)
+#define GOBJECT_AVAILABLE_STATIC_INLINE_IN_2_78 GLIB_UNAVAILABLE_STATIC_INLINE (2, 78)
+#define GOBJECT_AVAILABLE_MACRO_IN_2_78 GLIB_UNAVAILABLE_MACRO (2, 78)
+#define GOBJECT_AVAILABLE_ENUMERATOR_IN_2_78 GLIB_UNAVAILABLE_ENUMERATOR (2, 78)
+#define GOBJECT_AVAILABLE_TYPE_IN_2_78 GLIB_UNAVAILABLE_TYPE (2, 78)
+#else
+#define GOBJECT_AVAILABLE_IN_2_78 _GOBJECT_EXTERN
+#define GOBJECT_AVAILABLE_STATIC_INLINE_IN_2_78
+#define GOBJECT_AVAILABLE_MACRO_IN_2_78
+#define GOBJECT_AVAILABLE_ENUMERATOR_IN_2_78
+#define GOBJECT_AVAILABLE_TYPE_IN_2_78
+#endif
+
+#if GLIB_VERSION_MIN_REQUIRED >= GLIB_VERSION_2_80
+#define GOBJECT_DEPRECATED_IN_2_80 GOBJECT_DEPRECATED
+#define GOBJECT_DEPRECATED_IN_2_80_FOR(f) GOBJECT_DEPRECATED_FOR (f)
+#define GOBJECT_DEPRECATED_MACRO_IN_2_80 GLIB_DEPRECATED_MACRO
+#define GOBJECT_DEPRECATED_MACRO_IN_2_80_FOR(f) GLIB_DEPRECATED_MACRO_FOR (f)
+#define GOBJECT_DEPRECATED_ENUMERATOR_IN_2_80 GLIB_DEPRECATED_ENUMERATOR
+#define GOBJECT_DEPRECATED_ENUMERATOR_IN_2_80_FOR(f) GLIB_DEPRECATED_ENUMERATOR_FOR (f)
+#define GOBJECT_DEPRECATED_TYPE_IN_2_80 GLIB_DEPRECATED_TYPE
+#define GOBJECT_DEPRECATED_TYPE_IN_2_80_FOR(f) GLIB_DEPRECATED_TYPE_FOR (f)
+#else
+#define GOBJECT_DEPRECATED_IN_2_80 _GOBJECT_EXTERN
+#define GOBJECT_DEPRECATED_IN_2_80_FOR(f) _GOBJECT_EXTERN
+#define GOBJECT_DEPRECATED_MACRO_IN_2_80
+#define GOBJECT_DEPRECATED_MACRO_IN_2_80_FOR(f)
+#define GOBJECT_DEPRECATED_ENUMERATOR_IN_2_80
+#define GOBJECT_DEPRECATED_ENUMERATOR_IN_2_80_FOR(f)
+#define GOBJECT_DEPRECATED_TYPE_IN_2_80
+#define GOBJECT_DEPRECATED_TYPE_IN_2_80_FOR(f)
+#endif
+
+#if GLIB_VERSION_MAX_ALLOWED < GLIB_VERSION_2_80
+#define GOBJECT_AVAILABLE_IN_2_80 GOBJECT_UNAVAILABLE (2, 80)
+#define GOBJECT_AVAILABLE_STATIC_INLINE_IN_2_80 GLIB_UNAVAILABLE_STATIC_INLINE (2, 80)
+#define GOBJECT_AVAILABLE_MACRO_IN_2_80 GLIB_UNAVAILABLE_MACRO (2, 80)
+#define GOBJECT_AVAILABLE_ENUMERATOR_IN_2_80 GLIB_UNAVAILABLE_ENUMERATOR (2, 80)
+#define GOBJECT_AVAILABLE_TYPE_IN_2_80 GLIB_UNAVAILABLE_TYPE (2, 80)
+#else
+#define GOBJECT_AVAILABLE_IN_2_80 _GOBJECT_EXTERN
+#define GOBJECT_AVAILABLE_STATIC_INLINE_IN_2_80
+#define GOBJECT_AVAILABLE_MACRO_IN_2_80
+#define GOBJECT_AVAILABLE_ENUMERATOR_IN_2_80
+#define GOBJECT_AVAILABLE_TYPE_IN_2_80
+#endif
+
+#if GLIB_VERSION_MIN_REQUIRED >= GLIB_VERSION_2_82
+#define GOBJECT_DEPRECATED_IN_2_82 GOBJECT_DEPRECATED
+#define GOBJECT_DEPRECATED_IN_2_82_FOR(f) GOBJECT_DEPRECATED_FOR (f)
+#define GOBJECT_DEPRECATED_MACRO_IN_2_82 GLIB_DEPRECATED_MACRO
+#define GOBJECT_DEPRECATED_MACRO_IN_2_82_FOR(f) GLIB_DEPRECATED_MACRO_FOR (f)
+#define GOBJECT_DEPRECATED_ENUMERATOR_IN_2_82 GLIB_DEPRECATED_ENUMERATOR
+#define GOBJECT_DEPRECATED_ENUMERATOR_IN_2_82_FOR(f) GLIB_DEPRECATED_ENUMERATOR_FOR (f)
+#define GOBJECT_DEPRECATED_TYPE_IN_2_82 GLIB_DEPRECATED_TYPE
+#define GOBJECT_DEPRECATED_TYPE_IN_2_82_FOR(f) GLIB_DEPRECATED_TYPE_FOR (f)
+#else
+#define GOBJECT_DEPRECATED_IN_2_82 _GOBJECT_EXTERN
+#define GOBJECT_DEPRECATED_IN_2_82_FOR(f) _GOBJECT_EXTERN
+#define GOBJECT_DEPRECATED_MACRO_IN_2_82
+#define GOBJECT_DEPRECATED_MACRO_IN_2_82_FOR(f)
+#define GOBJECT_DEPRECATED_ENUMERATOR_IN_2_82
+#define GOBJECT_DEPRECATED_ENUMERATOR_IN_2_82_FOR(f)
+#define GOBJECT_DEPRECATED_TYPE_IN_2_82
+#define GOBJECT_DEPRECATED_TYPE_IN_2_82_FOR(f)
+#endif
+
+#if GLIB_VERSION_MAX_ALLOWED < GLIB_VERSION_2_82
+#define GOBJECT_AVAILABLE_IN_2_82 GOBJECT_UNAVAILABLE (2, 82)
+#define GOBJECT_AVAILABLE_STATIC_INLINE_IN_2_82 GLIB_UNAVAILABLE_STATIC_INLINE (2, 82)
+#define GOBJECT_AVAILABLE_MACRO_IN_2_82 GLIB_UNAVAILABLE_MACRO (2, 82)
+#define GOBJECT_AVAILABLE_ENUMERATOR_IN_2_82 GLIB_UNAVAILABLE_ENUMERATOR (2, 82)
+#define GOBJECT_AVAILABLE_TYPE_IN_2_82 GLIB_UNAVAILABLE_TYPE (2, 82)
+#else
+#define GOBJECT_AVAILABLE_IN_2_82 _GOBJECT_EXTERN
+#define GOBJECT_AVAILABLE_STATIC_INLINE_IN_2_82
+#define GOBJECT_AVAILABLE_MACRO_IN_2_82
+#define GOBJECT_AVAILABLE_ENUMERATOR_IN_2_82
+#define GOBJECT_AVAILABLE_TYPE_IN_2_82
+#endif
